@@ -1,8 +1,9 @@
 from celery import Celery
 from celery.utils.collections import force_mapping
-from dagster.seven import is_module_available
 from kombu import Queue
 
+from dagster._seven import is_module_available
+
 
 def make_app(app_args=None):
     return make_app_with_task_routes(
